@@ -1,5 +1,7 @@
 from rest_framework import serializers as rfs
 
+from certego_saas.settings import certego_apps_settings
+
 from .models import UserFeedback
 
 __all__ = [
@@ -23,5 +25,5 @@ class UserFeedbackSerializer(rfs.ModelSerializer):
         # below function does not raise any exception
         # because we should not respond with error
         # if the slack API fails since it's an internal use-case
-        feedback.send_to_slack()
+        feedback.send_to_slack(certego_apps_settings.DEFAULT_SLACK_CHANNEL)
         return feedback
