@@ -3,8 +3,8 @@ from typing import Tuple
 
 from rest_framework.test import APIClient, APITestCase
 
+from certego_saas.ext.test_utilities.no_logs_test_case import NoLogsTestCase
 from certego_saas.models import User
-from tests.no_logs_test_case import NoLogsTestCase
 
 
 def setup() -> Tuple[APIClient, User]:
